FrameMetricsSnapshot class

Frame metrics data snapshot.

Constructors

FrameMetricsSnapshot({required double currentFps, required double averageFps, required double minFps, required double maxFps, required double currentFrameDurationMs, required double targetBudgetMs, required int totalFrames, required int jankyFrames, required double jankPercentage, required List<double> frameHistoryMs})
const

Properties

averageFps double
final
currentFps double
final
currentFrameDurationMs double
final
frameHistoryMs List<double>
final
hashCode int
The hash code for this object.
no setterinherited
jankPercentage double
final
jankyFrames int
final
maxFps double
final
minFps double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetBudgetMs double
final
totalFrames int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited