NetworkTracker class

Extension point stub for Phase 2 network HTTP request latency tracking.

Constructors

NetworkTracker({required String method, required String url, required AppInspectorStore store})

Properties

hashCode int
The hash code for this object.
no setterinherited
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
final
store AppInspectorStore
final
url String
final

Methods

complete({int statusCode = 200, int responseSize = 0}) → void
Completes the network tracker with HTTP status code and response byte size.
fail({String? error}) → void
Marks network request as failed or timed out.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited