PerformanceAnalyzer class

Lightweight analysis engine that evaluates runtime events to extract actionable insights.

Constructors

PerformanceAnalyzer({required AppInspectorStore store})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store AppInspectorStore
final

Methods

analyze({FrameMetricsSnapshot? frameMetrics, MemoryMetricsSnapshot? memoryMetrics, WidgetMetricsSnapshot? widgetMetrics, NavigationMetricsSnapshot? navigationMetrics, ImageMetricsSnapshot? imageMetrics, ErrorMetricsSnapshot? errorMetrics}) List<PerformanceIssue>
Evaluates current metrics and returns a list of detected performance issues.
analyzePerformance({FrameMetricsSnapshot? frameMetrics, MemoryMetricsSnapshot? memoryMetrics, WidgetMetricsSnapshot? widgetMetrics, NavigationMetricsSnapshot? navigationMetrics, ImageMetricsSnapshot? imageMetrics, ErrorMetricsSnapshot? errorMetrics, List<AppInspectorEvent>? customEvents}) PerformanceAnalysisReport
Comprehensive developer-focused "Why Is My App Slow?" performance evaluation engine.
calculateScore({FrameMetricsSnapshot? frameMetrics, MemoryMetricsSnapshot? memoryMetrics, WidgetMetricsSnapshot? widgetMetrics, NavigationMetricsSnapshot? navigationMetrics, ImageMetricsSnapshot? imageMetrics, ErrorMetricsSnapshot? errorMetrics}) PerformanceScore
Computes transparent performance score with dynamic category re-weighting for unmeasured monitors.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited