CustomTracker class
Active tracker for measuring custom user operations.
Constructors
-
CustomTracker({required String name, required AppInspectorStore store, Map<
String, Object?> ? metadata})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stop(
{InspectorSeverity severity = InspectorSeverity.info, Map< String, Object?> ? extraMetadata}) → Duration - Stops timer and records custom performance event into store.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited