ImageMetricRecord class
Data class representing a recorded image performance metric.
Constructors
Properties
- displayHeight → double?
-
Displayed layout height in logical pixels.
final
- displayWidth → double?
-
Displayed layout width in logical pixels.
final
- estimatedDecodedBytes → int?
-
Estimated decoded RAM footprint in bytes (
width * height * 4bytes for 32-bit RGBA).final - hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Raw image pixel height.
final
- id → String
-
Unique identifier for this image metric.
final
- isOversized → bool
-
Whether raw image area significantly exceeds displayed area.
final
- loadDuration → Duration
-
Duration spent loading/resolving the image.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ImageLoadState
-
Load state (cacheHit, cacheMiss, failure).
final
- timestamp → DateTime
-
Timestamp when metric was recorded.
final
- urlOrKey → String
-
URL, asset key, or identifier for the image.
final
- width → int?
-
Raw image pixel width.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited