InspectorSession class
Represents a single runtime monitoring session.
Constructors
- InspectorSession({required String id, DateTime? startTime})
- Creates a new InspectorSession.
Properties
- duration → Duration
-
Calculates total elapsed duration of the session.
no setter
- endTime ↔ DateTime?
-
End timestamp of this session, if finished.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique session identifier.
final
- jankPercentage → double
-
Calculates overall jank percentage in this session.
no setter
- jankyFrames ↔ int
-
Total janky frames detected in this session.
getter/setter pair
- peakMemoryMb ↔ double
-
Highest peak memory recorded during this session (in MB).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime
-
Start timestamp of this session.
final
- totalFrames ↔ int
-
Total recorded frame count in this session.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Resets session counter metrics.
-
stop(
) → void - Marks the session as completed.
-
toJson(
) → Map< String, Object?> - Exports session summary as a JSON-serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited